@@ -1,9 +1,9 @@
-import base64
+from typing import List
 from nonebot.log import logger
 from nonebot.adapters.cqhttp import MessageSegment
 
-from .download import get_avatar, get_image, DownloadError
-from .functions import square, open_image
+from .download import download_image, DownloadError
+from .functions import load_image
 from .functions import petpet, kiss, rub, play, pat, rip, throw, crawl, support, always
 
 
@@ -51,34 +51,20 @@ commands = {
 }
 
 
-async def make_image(type: str, self_id: str, user_id: str = '', img_url: str = ''):
+async def make_image(type: str, images: List[str]):
     try:
         if type not in commands:
             return None
 
-        allow_gif = True if type in ['always'] else False
-
-        if user_id:
-            user_img = await get_avatar(user_id)
-            user_img = open_image(user_img, allow_gif)
-        elif img_url:
-            user_img = await get_image(img_url)
-            user_img = square(open_image(user_img, allow_gif))
-        else:
-            return None
-
+        convert = False if type in ['always'] else True
         func = commands[type]['func']
-
-        if type in ['kiss', 'rub']:
-            self_img = await get_avatar(self_id)
-            self_img = open_image(self_img, allow_gif)
-            result = await func(self_img, user_img)
-        else:
-            result = await func(user_img)
+        images = [load_image(await download_image(i), convert) for i in images]
+        result = await func(*images)
         return MessageSegment.image(result)
 
     except DownloadError:
         return '下载出错，请稍后再试'
     except Exception as e:
-        logger.warning(str(e))
+        logger.warning(
+            f"Error in make_image({type}, [{', '.join(images)}]): {e}")
         return '出错了，请稍后再试'
